@@ -564,8 +564,6 @@ def tunnel(env: Environment, address, target, ports):
     base_port = 4180
     # the time in seconds after which the port forwarding job gets cleanup up
     job_ttl = 3600
-    # the version of the socat image to use
-    socat_version = "1.7.4.1-r0-master-4"
 
     # remove any resources we created when shutting down
     @atexit.register
@@ -579,10 +577,10 @@ def tunnel(env: Environment, address, target, ports):
     kube_config.update_token()
 
     # generate socat container specs for each port
-    containers = generate_containers(target, ports, base_port, socat_version)
+    containers = generate_containers(target, ports, base_port)
 
     # template of the job to apply
-    job_spec = generate_job(containers, job_name, job_ttl, socat_version)
+    job_spec = generate_job(containers, job_name, job_ttl)
 
     # submit the job to kubernetes
     cmdline = ("apply", "-f", "-")
@@ -632,21 +630,37 @@ def tunnel(env: Environment, address, target, ports):
     env.kubectl.run(cmdline, check=True, stdout=subprocess.PIPE)
 
 
-def generate_containers(target, ports, base_port, socat_version):
+def latest_socat_image():
+    docker_registry = "registry.opensource.zalan.do"
+    team = "teapot"
+    artifact = "socat"
+
+    response = requests.get("https://{}/teams/{}/artifacts/{}/tags".format(docker_registry, team, artifact), timeout=10)
+    response.raise_for_status()
+
+    production_ready_images = [image for image in response.json() if image["status"] == "production_ready"]
+    if not production_ready_images:
+        raise Exception("No usable images found for {}/{}/{}".format(docker_registry, team, artifact))
+
+    return "{}/{}/{}:{}".format(docker_registry, team, artifact, production_ready_images[-1]["name"])
+
+
+def generate_containers(target, ports, base_port):
     containers = []
+    socat_image = latest_socat_image()
 
     for i, port in enumerate(ports):
         local_port = base_port + i
         remote_port = port[-1]
-        containers.append(generate_container(target, local_port, remote_port, socat_version))
+        containers.append(generate_container(target, local_port, remote_port, socat_image))
 
     return containers
 
 
-def generate_container(target, local_port, remote_port, socat_version):
+def generate_container(target, local_port, remote_port, socat_image):
     return {
         "name": "socat-{}".format(remote_port),
-        "image": "registry.opensource.zalan.do/teapot/socat:{}".format(socat_version),
+        "image": socat_image,
         "args": [
             "-d",
             "-d",
@@ -663,7 +677,7 @@ def generate_container(target, local_port, remote_port, socat_version):
     }
 
 
-def generate_job(containers, name, ttl, socat_version):
+def generate_job(containers, name, ttl):
     return {
         "apiVersion": "batch/v1",
         "kind": "Job",
@@ -676,7 +690,7 @@ def generate_job(containers, name, ttl, socat_version):
             "activeDeadlineSeconds": ttl,
             "ttlSecondsAfterFinished": 0,
             "template": {
-                "metadata": {"labels": {"application": "teapot-port-forward", "version": socat_version}},
+                "metadata": {"labels": {"application": "teapot-port-forward"}},
                 "spec": {"automountServiceAccountToken": False, "restartPolicy": "Never", "containers": containers},
             },
         },
